@@ -1,9 +1,12 @@
+from .statcast.catcher_throwing import catcher_throwing
 from .statcast.minor_statcast_search import (
     minor_statcast_batter_search,
     minor_statcast_pitcher_search,
     minor_statcast_search,
 )
 from .statcast.mlbam_id_search import mlbam_id_search
+from .statcast.runner_basestealing import runner_basestealing
+from .statcast.runner_extra_bases_taken import runner_extra_bases_taken
 from .statcast.statcast_search import (
     statcast_batter_search,
     statcast_pitcher_search,
@@ -18,4 +21,7 @@ __all__ = [
     'minor_statcast_pitcher_search',
     'minor_statcast_batter_search',
     'mlbam_id_search',
+    'catcher_throwing',
+    'runner_basestealing',
+    'runner_extra_bases_taken',
 ]
